/*
 * Common system pager functionality.
 *
 * Copyright (C) 2022, 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <l4/re/env.h>

#include <mem/memory_utils.h>

#include "pager.h"



/* Initialise common functionality. */

ExecPager::ExecPager(address_t start, address_t end)
: _area(start, end)
{
}

/* Necessary virtual destructor. */

ExecPager::~ExecPager()
{
}



/* Add an area to the pager. */

void ExecPager::add(MemoryArea &area)
{
  _area.add(area);
}

/* Remove an area from the pager. */

void ExecPager::remove(MemoryArea &area)
{
  _area.remove(area);
}



/* Find an area suitable for attaching a memory region. */

long ExecPager::find(address_t *start, address_t *size, map_flags_t flags,
                     unsigned char align, MemoryArea **area)
{
  if (align < L4_PAGESHIFT)
    align = L4_PAGESHIFT;

  /* Attempt to find an address for the specified region, starting from
     any indicated address. */

  return _area.find(start, size, flags, align, area);
}

/* vim: tabstop=2 expandtab shiftwidth=2
*/
